==> camel-k-model-v1-6.4.0-sources.jar: io/fabric8/camelk/v1/ResourceSpecFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ResourceSpecFluentImpl<A extends ResourceSpecFluent<A>> extends BaseFluent<A> implements ResourceSpecFluent<A>{
  public ResourceSpecFluentImpl() {
  }
  public ResourceSpecFluentImpl(ResourceSpec instance) {
    this.withCompression(instance.getCompression()); 
    this.withContent(instance.getContent()); 
    this.withContentKey(instance.getContentKey()); 
    this.withContentRef(instance.getContentRef()); 
    this.withContentType(instance.getContentType()); 
    this.withMountPath(instance.getMountPath()); 
    this.withName(instance.getName()); 
    this.withPath(instance.getPath()); 
    this.withRawContent(instance.getRawContent()); 
    this.withType(instance.getType()); 
  }
  private Boolean compression;
  private String content;
  private String contentKey;
  private String contentRef;
  private String contentType;
  private String mountPath;
  private String name;
  private String path;
  private String rawContent;
  private String type;
  public Boolean getCompression() {
    return this.compression;
  }
  public A withCompression(Boolean compression) {
    this.compression=compression; return (A) this;
  }
  public Boolean hasCompression() {
    return this.compression != null;
  }
  public String getContent() {
    return this.content;
  }
  public A withContent(String content) {
    this.content=content; return (A) this;
  }
  public Boolean hasContent() {
    return this.content != null;
  }
  public String getContentKey() {
    return this.contentKey;
  }
  public A withContentKey(String contentKey) {
    this.contentKey=contentKey; return (A) this;
  }
  public Boolean hasContentKey() {
    return this.contentKey != null;
  }
  public String getContentRef() {
    return this.contentRef;
  }
  public A withContentRef(String contentRef) {
    this.contentRef=contentRef; return (A) this;
  }
  public Boolean hasContentRef() {
    return this.contentRef != null;
  }
  public String getContentType() {
    return this.contentType;
  }
  public A withContentType(String contentType) {
    this.contentType=contentType; return (A) this;
  }
  public Boolean hasContentType() {
    return this.contentType != null;
  }
  public String getMountPath() {
    return this.mountPath;
  }
  public A withMountPath(String mountPath) {
    this.mountPath=mountPath; return (A) this;
  }
  public Boolean hasMountPath() {
    return this.mountPath != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getRawContent() {
    return this.rawContent;
  }
  public A withRawContent(String rawContent) {
    this.rawContent=rawContent; return (A) this;
  }
  public Boolean hasRawContent() {
    return this.rawContent != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceSpecFluentImpl that = (ResourceSpecFluentImpl) o;
    if (compression != null ? !compression.equals(that.compression) :that.compression != null) return false;
    if (content != null ? !content.equals(that.content) :that.content != null) return false;
    if (contentKey != null ? !contentKey.equals(that.contentKey) :that.contentKey != null) return false;
    if (contentRef != null ? !contentRef.equals(that.contentRef) :that.contentRef != null) return false;
    if (contentType != null ? !contentType.equals(that.contentType) :that.contentType != null) return false;
    if (mountPath != null ? !mountPath.equals(that.mountPath) :that.mountPath != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (rawContent != null ? !rawContent.equals(that.rawContent) :that.rawContent != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(compression,  content,  contentKey,  contentRef,  contentType,  mountPath,  name,  path,  rawContent,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (compression != null) { sb.append("compression:"); sb.append(compression + ","); }
    if (content != null) { sb.append("content:"); sb.append(content + ","); }
    if (contentKey != null) { sb.append("contentKey:"); sb.append(contentKey + ","); }
    if (contentRef != null) { sb.append("contentRef:"); sb.append(contentRef + ","); }
    if (contentType != null) { sb.append("contentType:"); sb.append(contentType + ","); }
    if (mountPath != null) { sb.append("mountPath:"); sb.append(mountPath + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (rawContent != null) { sb.append("rawContent:"); sb.append(rawContent + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  public A withCompression() {
    return withCompression(true);
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/ResourceSpecFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ResourceSpecFluentImpl<A extends ResourceSpecFluent<A>> extends BaseFluent<A> implements ResourceSpecFluent<A>{
  public ResourceSpecFluentImpl() {
  }
  public ResourceSpecFluentImpl(ResourceSpec instance) {
    if (instance != null) {
      this.withCompression(instance.getCompression());
      this.withContent(instance.getContent());
      this.withContentKey(instance.getContentKey());
      this.withContentRef(instance.getContentRef());
      this.withContentType(instance.getContentType());
      this.withMountPath(instance.getMountPath());
      this.withName(instance.getName());
      this.withPath(instance.getPath());
      this.withRawContent(instance.getRawContent());
      this.withType(instance.getType());
    }
  }
  private Boolean compression;
  private String content;
  private String contentKey;
  private String contentRef;
  private String contentType;
  private String mountPath;
  private String name;
  private String path;
  private String rawContent;
  private String type;
  public Boolean getCompression() {
    return this.compression;
  }
  public A withCompression(Boolean compression) {
    this.compression=compression; return (A) this;
  }
  public Boolean hasCompression() {
    return this.compression != null;
  }
  public String getContent() {
    return this.content;
  }
  public A withContent(String content) {
    this.content=content; return (A) this;
  }
  public Boolean hasContent() {
    return this.content != null;
  }
  public String getContentKey() {
    return this.contentKey;
  }
  public A withContentKey(String contentKey) {
    this.contentKey=contentKey; return (A) this;
  }
  public Boolean hasContentKey() {
    return this.contentKey != null;
  }
  public String getContentRef() {
    return this.contentRef;
  }
  public A withContentRef(String contentRef) {
    this.contentRef=contentRef; return (A) this;
  }
  public Boolean hasContentRef() {
    return this.contentRef != null;
  }
  public String getContentType() {
    return this.contentType;
  }
  public A withContentType(String contentType) {
    this.contentType=contentType; return (A) this;
  }
  public Boolean hasContentType() {
    return this.contentType != null;
  }
  public String getMountPath() {
    return this.mountPath;
  }
  public A withMountPath(String mountPath) {
    this.mountPath=mountPath; return (A) this;
  }
  public Boolean hasMountPath() {
    return this.mountPath != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getRawContent() {
    return this.rawContent;
  }
  public A withRawContent(String rawContent) {
    this.rawContent=rawContent; return (A) this;
  }
  public Boolean hasRawContent() {
    return this.rawContent != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceSpecFluentImpl that = (ResourceSpecFluentImpl) o;
    if (!java.util.Objects.equals(compression, that.compression)) return false;

    if (!java.util.Objects.equals(content, that.content)) return false;

    if (!java.util.Objects.equals(contentKey, that.contentKey)) return false;

    if (!java.util.Objects.equals(contentRef, that.contentRef)) return false;

    if (!java.util.Objects.equals(contentType, that.contentType)) return false;

    if (!java.util.Objects.equals(mountPath, that.mountPath)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(rawContent, that.rawContent)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(compression,  content,  contentKey,  contentRef,  contentType,  mountPath,  name,  path,  rawContent,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (compression != null) { sb.append("compression:"); sb.append(compression + ","); }
    if (content != null) { sb.append("content:"); sb.append(content + ","); }
    if (contentKey != null) { sb.append("contentKey:"); sb.append(contentKey + ","); }
    if (contentRef != null) { sb.append("contentRef:"); sb.append(contentRef + ","); }
    if (contentType != null) { sb.append("contentType:"); sb.append(contentType + ","); }
    if (mountPath != null) { sb.append("mountPath:"); sb.append(mountPath + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (rawContent != null) { sb.append("rawContent:"); sb.append(rawContent + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  public A withCompression() {
    return withCompression(true);
  }
  
}
